==> klat4-0.5.2.tar.bz2: klat4-0.5.2/klatexecconfig.cpp <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klatexecconfig.h"
#include <kconfiggroup.h>
#include <kconfig.h>
//delete
#include <kmessagebox.h>
#include <stdio.h>


KlatExecConfig::KlatExecConfig()
{
	it = execEntries.end();
}

KlatExecConfig::~KlatExecConfig()
{
}

#define EXECMENUNAME 	"ExecutionMenu"
#define KEYNAME 	"Item_"
#define SAVEFILEYES 	"yes"
#define SAVEFILENO 	"no"


void KlatExecConfig::read(KConfig *cfg)
{
	int count;
	bool done;

	KConfigGroup execConfig(cfg,EXECMENUNAME);
	execEntries.clear();

	count = 0;
	done = false;
	while (!done)
	{
		QString key = KEYNAME + QString::number(count);

		if (!execConfig.hasKey(key))
			done = true;
		else
		{
			QStringList lst = execConfig.readEntry(key,QStringList());
			
			if (!lst.empty())
			{
				QStringList::const_iterator i;
				QString section,menuname,cmd,cmdline;
				KShortcut shortcut;

				i = lst.begin();
				section = (*i);
				i++;
				 if(i != lst.end())
				{
					menuname = (*i);
					i++;
					if (i != lst.end())
					{
						cmd = (*i);
						i++;
						if(i != lst.end())
						{
							cmdline = (*i);
							i++;
							if (i != lst.end())
								shortcut = KShortcut(*i);
						}
					}
				}
				if(section == "compile" || section == "convert" || section == "view")
					execEntries.push_back(KlatExecMenuEntry(section,menuname,cmd,cmdline,shortcut));
			}
		}
		count++;
	}

	it = execEntries.end();
}

void KlatExecConfig::write(KConfig *cfg)
{
	std::list<KlatExecMenuEntry>::const_iterator i;
	int count;

	KConfigGroup execConfig(cfg,EXECMENUNAME);

	for (i = execEntries.begin(), count=0; i != execEntries.end() ; ++i,count++)
	{
		QString key = KEYNAME + QString::number(count);
		QStringList lst;
		
		lst.push_back((*i).section());
		lst.push_back((*i).menuName());
		lst.push_back((*i).command());
		lst.push_back((*i).commandLine());
		lst.push_back((*i).shortcut().toString());
		execConfig.writeEntry(key,lst);
	}
	cfg->sync();
}

bool KlatExecConfig::gotoFirstEntry()
{
	if (execEntries.empty())
		return false;
	it = execEntries.begin();
	return true;
}

bool KlatExecConfig::gotoNextEntry()
{
	if (execEntries.empty())
		return false;
	if (it == execEntries.end())
		return false;
	it++;
	if (it == execEntries.end())
		return false;
	return true;
}

bool KlatExecConfig::gotoEntry(QString str)
{
	if (execEntries.empty())
		return false;
	
	if (str.length() == 0) // make sure no item is selected
	{
		it = execEntries.end();
		return true;
	}
	
	it = execEntries.begin();
	while (menuName() != str)
	{
		it++;
		if (it == execEntries.end())
			return false;
	}
	return true;
}

bool KlatExecConfig::gotoEntry(int index)
{
	if (execEntries.empty())
		return false;
	
	if (index < 0) // make sure no item is selected
	{
		it = execEntries.end();
		return true;
	}
	
	int i = 0;
	
	it = execEntries.begin();
	while (i < index)
	{
		it++;
		i++;
		if (it == execEntries.end())
			return false;
	}
	return true;
}

QString KlatExecConfig::section()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).section();
}

QString KlatExecConfig::menuName()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).menuName();
}

QString KlatExecConfig::command()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).command();
}

QString KlatExecConfig::commandLine()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).commandLine();
}

bool KlatExecConfig::saveFirst()
{
	if (execEntries.empty())
		return false;
	if (it == execEntries.end())
		return false;
	return (*it).saveFirst();
}

KShortcut KlatExecConfig::shortcut()
{
	KShortcut c;

	if (execEntries.empty())
		return c;
	if (it == execEntries.end())
		return c;
	c = (*it).shortcut();
	return c;
}

KlatExecMenuEntry KlatExecConfig::entry()
{
	KlatExecMenuEntry e("","","","",KShortcut());
	
	if (execEntries.empty())
		return e;
	if (it == execEntries.end())
		return e;
	return (*it);
}

void KlatExecConfig::insertAfterCurrent(const KlatExecMenuEntry &entry)
{
	if (execEntries.empty() || it == execEntries.end())
	{
		execEntries.push_front(entry);
	
		it = execEntries.begin();
	}
	else
	{
		it++;
		it = execEntries.insert(it,entry);
	}
}

void KlatExecConfig::deleteCurrent()
{
	if (execEntries.empty())
		return;
	if (it == execEntries.end())
		return;
	execEntries.erase(it);
	it = execEntries.end();
}
	
void KlatExecConfig::changeCurrent(const KlatExecMenuEntry &m)
{
	if (execEntries.empty())
		return;
	if (it == execEntries.end())
		return;
	(*it) = m;
}

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/klatexecconfig.cpp <==
/*
    Klat4 - A LaTeX editor for KDE4

    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "klatexecconfig.h"

#include <KConfigGroup>
#include <KConfig>

KlatExecConfig::KlatExecConfig()
{
	it = execEntries.end();
}

KlatExecConfig::~KlatExecConfig()
{
}

#define EXECMENUNAME 	"Execution Menu"
#define KEYNAME 	"Item_"

#define COMPSECT	"compile"
#define CONVSECT	"convert"
#define VIEWSECT	"view"

void KlatExecConfig::read(KConfig *cfg)
{
	int count;
	bool done;

	KConfigGroup execConfig(cfg,EXECMENUNAME);
	execEntries.clear();

	count = 0;
	done = false;
	while (!done)
	{
		QString key = KEYNAME + QString::number(count);

		if (!execConfig.hasKey(key))
			done = true;
		else
		{
			QStringList lst = execConfig.readEntry(key,QStringList());
			
			if (!lst.empty())
			{
				QStringList::const_iterator i;
				QString section,menuname,cmd,cmdline;
				KShortcut shortcut;

				i = lst.begin();
				section = (*i);
				i++;
				 if(i != lst.end())
				{
					menuname = (*i);
					i++;
					if (i != lst.end())
					{
						cmd = (*i);
						i++;
						if(i != lst.end())
						{
							cmdline = (*i);
							i++;
							if (i != lst.end())
								shortcut = KShortcut(*i);
						}
					}
				}
				if(section == COMPSECT || section == CONVSECT || section == VIEWSECT)
					execEntries.append(KlatExecMenuEntry(section,menuname,cmd,cmdline,shortcut));
			}
		}
		count++;
	}

	it = execEntries.end();
}

void KlatExecConfig::write(KConfig *cfg)
{
	QList<KlatExecMenuEntry>::const_iterator i;
	int count;

	KConfigGroup execConfig(cfg,EXECMENUNAME);

	execConfig.deleteGroup();
	for (i = execEntries.constBegin(), count=0; i != execEntries.constEnd() ; ++i,count++)
	{
		QString key = KEYNAME + QString::number(count);
		QStringList lst;
		
		lst.append((*i).section());
		lst.append((*i).menuName());
		lst.append((*i).command());
		lst.append((*i).commandLine());
		lst.append((*i).shortcut().toString());
		execConfig.writeEntry(key,lst);
	}
	cfg->sync();
}

bool KlatExecConfig::gotoFirstEntry()
{
	if (execEntries.empty())
		return false;
	it = execEntries.begin();
	return true;
}

bool KlatExecConfig::gotoNextEntry()
{
	if (execEntries.empty())
		return false;
	if (it == execEntries.end())
		return false;
	it++;
	if (it == execEntries.end())
		return false;
	return true;
}

bool KlatExecConfig::gotoSectionEndEntry(const QString &sect)
{
	if (execEntries.empty())
		return false;
	it = execEntries.end();
	if(sect == SECTVIEW)
	{
		while((section()!=SECTVIEW)&&(section()!=SECTCONV)&&(section()!=SECTCOMP)&&(it!=execEntries.begin()))
			it--;
	}
	if(sect == SECTCONV)
	{
		while((section()!=SECTCONV)&&(section()!=SECTCOMP)&&(it!=execEntries.begin()))
			it--;
	}
	if(sect == SECTCOMP)
	{
		while((section()!=SECTCOMP)&&(it!=execEntries.begin()))
			it--;
	}
	return true;
}

bool KlatExecConfig::gotoEntry(QString str)
{
	if (execEntries.empty())
		return false;
	
	if (str.length() == 0) // make sure no item is selected
	{
		it = execEntries.end();
		return true;
	}
	
	it = execEntries.begin();
	while (menuName() != str)
	{
		it++;
		if (it == execEntries.end())
			return false;
	}
	return true;
}

bool KlatExecConfig::gotoEntry(int index)
{
	if (execEntries.empty())
		return false;
	
	if (index < 0) // make sure no item is selected
	{
		it = execEntries.end();
		return true;
	}
	
	int i = 0;
	
	it = execEntries.begin();
	while (i < index)
	{
		it++;
		i++;
		if (it == execEntries.end())
			return false;
	}
	return true;
}

int KlatExecConfig::position()
{
	int pos=0;
	if (execEntries.empty())
		return -1;
	while (it!=execEntries.begin())
	{
		it--;
		pos++;
	}
	gotoEntry(pos);
	return pos;
}

QString KlatExecConfig::section()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).section();
}

QString KlatExecConfig::menuName()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).menuName();
}

QString KlatExecConfig::command()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).command();
}

QString KlatExecConfig::commandLine()
{
	if (execEntries.empty())
		return QString("");
	if (it == execEntries.end())
		return QString("");
	return (*it).commandLine();
}

bool KlatExecConfig::saveFirst()
{
	if (execEntries.empty())
		return false;
	if (it == execEntries.end())
		return false;
	return (*it).saveFirst();
}

KShortcut KlatExecConfig::shortcut()
{
	KShortcut c;

	if (execEntries.empty())
		return c;
	if (it == execEntries.end())
		return c;
	c = (*it).shortcut();
	return c;
}

KlatExecMenuEntry KlatExecConfig::entry()
{
	KlatExecMenuEntry e("","","","",KShortcut());
	
	if (execEntries.empty())
		return e;
	if (it == execEntries.end())
		return e;
	return (*it);
}

void KlatExecConfig::insertAfterCurrent(const KlatExecMenuEntry &entry)
{
	if (execEntries.empty() || it == execEntries.end())
	{
		execEntries.push_front(entry);
	
		it = execEntries.begin();
	}
	else
	{
		it++;
		it = execEntries.insert(it,entry);
	}
}

void KlatExecConfig::deleteCurrent()
{
	if (execEntries.empty())
		return;
	if (it == execEntries.end())
		return;
	execEntries.erase(it);
	it = execEntries.end();
}
	
void KlatExecConfig::changeCurrent(const KlatExecMenuEntry &m)
{
	if (execEntries.empty())
		return;
	if (it == execEntries.end())
		return;
	(*it) = m;
}
